
import pygame
import FontPainter
import WiLabel
import WiButton
import VBox
import HBox
import WiSpace
import DoingPage
import Animation
import ui
import pygame
import logging

class ActivitySelectionPage:
    def __init__(self, logic):
        self.logic = logic
        self.previouslyAvailable = {}
        self.guiNeedsUpdate = True
        self.selectedActivity = None
        self.gui = []
        self.animation = Animation.Animation(self.logic.player, {})
        self.goal = ("health", 100, "Excellent, you are ready to quit the game.")

    def update(self):
        if self.guiNeedsUpdate:
            self.gui = []
            self.guiNeedsUpdate = False
            hbox = HBox.HBox()
            hbox.setPos((10,20))
            self.gui.append(hbox)

            vbox = VBox.VBox()
            vbox.addWidget(WiLabel.WiLabel("Select Activity:"))
            self.createActivityButtons(vbox)
            hbox.addWidget(vbox)
            hbox.addWidget(WiSpace.WiSpace(20,0))
            if self.selectedActivity is not None:
                hbox.addWidget(self.createInfo())

            self.gui.append(self.createStats())
            self.gui.append(self.createGoalInfo())

    def event(self, e):
        if e.type == pygame.MOUSEBUTTONDOWN:
            for widget in self.gui:
                newState = widget.onClick(e)
                if newState:
                    return newState

    def drawOn(self, screen):
        bgColor = ui.BG_COLOR
        screen.fill(bgColor)
        self.animation.drawOn(screen)
        for widget in self.gui:
            widget.drawOn(screen)

    def createActivityButton(self, activity, state="normal"):
        color = ui.LINK_COLOR
        if self.selectedActivity is activity:
            color = ui.SELECTED_COLOR
        elif state == "new":
            color = ui.NEW_LINK_COLOR
        elif state == "denied":
            color = ui.DISABLED_COLOR
        label = WiLabel.WiLabel("> " + activity.name, color=color)
        return WiButton.WiButton(label, self.onActivitySelected, [activity])

    def createStats(self):
        stats = VBox.VBox()
        stats.addWidget(WiLabel.WiLabel("Player Stats", color=ui.HEADING_COLOR))
        rows = []
        for property in self.logic.model.getProperties():
            value1 = "%s:" % property.name
            value2 = "%s" % self.logic.player.getProperty(property.name)
            rows.append([value1, value2])
        stats.addWidget(ui.createTable(rows))

        screen = pygame.display.get_surface()
        stats.setPos((screen.get_width() - 5 - stats.getW(),
            screen.get_height() - 5 - stats.getH()))
        return stats

    def createInfo(self):
        vbox = VBox.VBox()
        text = "== %s ==" % self.selectedActivity.name
        vbox.addWidget(WiLabel.WiLabel(
            text, color=ui.HEADING_COLOR))

        rows = []
        sorted = self.selectedActivity.getSortedChanges()
        for propertyName, change in sorted:
            value1 = "%s:" % propertyName
            if change < 0:
                value2 = str(change)
            else:
                value2 = "+" + str(change)
            rows.append([value1, value2])

        table = ui.createTable(rows)

        vbox.addWidget(table)
        if self.selectedActivity.isAvailable(self.logic.player):
            button = WiButton.WiButton(WiLabel.WiLabel(
                "[ Take ]", color=ui.LINK_COLOR),
                self.onActivityTaken, [])
            vbox.addWidget(button)
        else:
            needs = self.selectedActivity.getSortedPrereqs()
            if len(needs) > 0:
                vbox.addWidget(WiLabel.WiLabel("Needs:", color=ui.DISABLED_COLOR))
                rows = []
                for propertyName, needed in needs:
                    value1 = "%s:" % propertyName
                    value2 = str(needed)
                    rows.append([value1, value2])
                table = ui.createTable(rows)
                vbox.addWidget(table)

        return vbox

    def onActivitySelected(self, activity):
        logging.debug("onActivitySelected: %s", activity)
        self.selectedActivity = activity
        self.guiNeedsUpdate = True

    def onActivityTaken(self):
        logging.debug("onActivityTaken: %s", self.selectedActivity)
        self.previouslyAvailable = self.logic.getAvailableActivities()
        self.guiNeedsUpdate = True
        return DoingPage.DoingPage(self.logic, self.selectedActivity, self)

    def getNewActivities(self):
        newActivities = []
        for activity in self.logic.getAvailableActivities():
            if activity not in self.previouslyAvailable:
                newActivities.append(activity)
        newActivities.sort()
        return newActivities

    def createActivityButtons(self, vbox):
        newActivities = self.getNewActivities()
        logging.debug("newActivities: %s", newActivities)
        available = self.logic.getAvailableActivities()
        for activity in newActivities:
            vbox.addWidget(self.createActivityButton(activity, "new"))
        for activity in available:
            if activity not in newActivities:
                vbox.addWidget(self.createActivityButton(activity))
        for activity in self.logic.model.getActivities():
            if activity not in available:
                vbox.addWidget(self.createActivityButton(activity, "denied"))

    def createGoalInfo(self):
        area = VBox.VBox()
        text = "Goal: %s=%s" % (self.goal[0], self.goal[1])
        color = ui.TEXT_COLOR
        if self.logic.player.getProperty(self.goal[0]) >= self.goal[1]:
            color = ui.DONE_COLOR
            area.addWidget(WiLabel.WiLabel(text, color=color))
            area.addWidget(WiLabel.WiLabel(self.goal[2], color=color))
        else:
            area.addWidget(WiLabel.WiLabel(text, color=color))
        screen = pygame.display.get_surface()
        area.setPos((5, screen.get_height() - 5 - area.getH()))
        return area

