
class Animation:
    def __init__(self, player, diffs):
        self.player = player
        self.diffs = diffs
        self.cycles = 10
        self.phase = 0
        self.pos = None
        self.wait = 5
        self.waiting = 2

    def setPos(self, pos):
        self.pos = pos

    def update(self):
        if (self.phase == 0 or self.phase == self.cycles - 1) and self.waiting < self.wait:
            self.waiting += 1
            return
        self.waiting = 0
        self.phase = (self.phase + 1) % self.cycles

    def drawOn(self, screen):
        if self.pos is None:
            self.pos = (screen.get_width()//2, screen.get_height()//2)
        for property in self.player.model.getProperties():
            value = self.getProperty(property.name)
            property.expressOn(screen, self.pos, value, self)

    def getProperty(self, key):
        newValue = self.player.getProperty(key)
        if not key in self.diffs:
            return newValue
        diff = self.diffs[key]
        oldValue = newValue - diff
        return oldValue + self.phase * diff/float(self.cycles)

