
import VBox
import WiLabel
import WiButton
import ui
import pygame
import ActivitySelectionPage
import Animation
import logging

class DoingPage:
    def __init__(self, logic, activity, nextState):
        self.logic = logic
        self.activity = activity
        self.nextState = nextState
        self.gui = None
        self.animation = None
        self.firstRun = True

    def update(self):
        if self.firstRun:
            self.firstRun = False
            diffs = self.logic.doActivity(self.activity)
            self.createGui(diffs)
            self.createAnimation(diffs)

        self.animation.update()

    def event(self, e):
        if e.type == pygame.MOUSEBUTTONDOWN:
            return self.gui.onClick(e)

    def drawOn(self, screen):
        bgColor = ui.BG_COLOR
        screen.fill(bgColor)
        self.animation.drawOn(screen)
        self.gui.drawOn(screen)

    def onOk(self):
        logging.debug("onOk")
        return self.nextState

    def createAnimation(self, diffs):
        self.animation = Animation.Animation(self.logic.player, diffs)

    def createGui(self, diffs):
        self.gui = VBox.VBox()
        self.gui.setPos((10,20))
        text = "Doing %s" % self.activity.name
        self.gui.addWidget(ui.createHeading(text))

        rows = []
        for property in self.logic.model.getProperties():
            value1 = "%s:" % property.name
            value2 = "%s" % self.logic.player.getProperty(property.name)
            value3 = ""
            if property.name in diffs:
                change = diffs[property.name]
                if change >= 0:
                    change = "+" + str(change)
                value3 = "...  %s" % change
            rows.append([value1, value2, value3])
        self.gui.addWidget(ui.createTable(rows))

        okLabel = WiLabel.WiLabel("[====== OK ======]", color=ui.LINK_COLOR)
        self.gui.addWidget(WiButton.WiButton(okLabel, self.onOk, []))
